@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,18 @@
 
 #include <glib.h>
 
-#ifndef TYPEDEF_GDM_CONNECTION
-#define TYPEDEF_GDM_CONNECTION
 typedef struct _GdmConnection GdmConnection;
-#endif  /* TYPEDEF_GDM_CONNECTION */
+
+#include "display.h"
+
+/* Macros to check authentication level */
+#define GDM_CONN_AUTHENTICATED(conn) \
+	((gdm_connection_get_user_flags (conn) & GDM_SUP_FLAG_AUTHENTICATED) || \
+	 (gdm_connection_get_user_flags (conn) & GDM_SUP_FLAG_AUTH_GLOBAL))
+
+#define GDM_CONN_AUTH_GLOBAL(conn) \
+	 (gdm_connection_get_user_flags (conn) & GDM_SUP_FLAG_AUTH_GLOBAL)
+
 
 /* Something that will get stuff line by line */
 typedef void (* GdmConnectionHandler) (GdmConnection *conn,
@@ -53,6 +61,10 @@ void		gdm_connection_set_handler (GdmConnection *conn,
 					    gpointer data,
 					    GDestroyNotify destroy_notify);
 
+gboolean	gdm_connection_get_nonblock   (GdmConnection *conn);
+void		gdm_connection_set_nonblock   (GdmConnection *conn,
+					       gboolean nonblock);
+
 guint32		gdm_connection_get_user_flags (GdmConnection *conn);
 void		gdm_connection_set_user_flags (GdmConnection *conn,
 					       guint32 flags);
@@ -67,7 +79,17 @@ void		gdm_connection_set_user_flags (GdmConnection *conn,
 			gdm_connection_set_user_flags (conn, _flags);		\
 		}
 
-void		gdm_connection_close (GdmConnection *conn);
+GdmDisplay *	gdm_connection_get_display            (GdmConnection *conn);
+void		gdm_connection_set_display            (GdmConnection *conn,
+					               GdmDisplay *disp);
+int		gdm_connection_is_server_busy         (GdmConnection *conn);
+void		gdm_kill_subconnections_with_display  (GdmConnection *conn,
+						       GdmDisplay *disp);
+
+int		gdm_connection_get_message_count      (GdmConnection *conn);
+
+
+void		gdm_connection_close                  (GdmConnection *conn);
 
 #endif /* GDM_NET_H */
 
