@@ -634,7 +634,7 @@ gdm_exec_wait (char * const *argv,
 	    g_access (argv[0], X_OK) != 0)
 		return -1;
 
-	g_debug ("Forking extra process: %s", argv[0]);
+	gdm_debug ("Forking extra process: %s", argv[0]);
 
 	pid = gdm_fork_extra ();
 	if (pid == 0) {
@@ -899,7 +899,7 @@ gdm_address_peek_local_list (void)
 	static GList *the_list = NULL;
 	static time_t last_time = 0;
 	char hostbuf[BUFSIZ];
-	struct addrinfo hints;
+	struct addrinfo hints;  
 	struct addrinfo *result;
 	struct addrinfo *res;
 
@@ -920,10 +920,17 @@ gdm_address_peek_local_list (void)
 		snprintf (hostbuf, BUFSIZ-1, "localhost");
 	}
 
-	memset (&hints, 0, sizeof (hints));
+	memset (&hints, 0, sizeof (hints)); 
+
 	hints.ai_family = AF_INET;
+
 #ifdef ENABLE_IPV6
-	hints.ai_family |= AF_INET6;
+	hints.ai_family = AF_INET6;
+#endif  
+
+#ifdef ENABLE_IPV6 
+	if (getaddrinfo (hostbuf, NULL, &hints, &result) != 0) {
+		hints.ai_family = AF_INET;
 #endif
 
 	if (getaddrinfo (hostbuf, NULL, &hints, &result) != 0) {
@@ -932,6 +939,9 @@ gdm_address_peek_local_list (void)
 		return NULL;
 	}
 
+#ifdef ENABLE_IPV6        
+	}
+#endif    
 	for (res = result; res != NULL; res = res->ai_next) {
 		struct sockaddr_storage *sa;
 
